import{d as t,o,X as s,b as d,u as r,bx as _,$ as c}from"./vue-router.9fdef1c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="18831505-acb4-427b-a5a5-1bc69b5bf169",e._sentryDebugIdIdentifier="sentry-dbid-18831505-acb4-427b-a5a5-1bc69b5bf169")}catch{}})();const i={class:"centered"},b=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[d(r(_))]))}});const p=c(b,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.13e81899.js.map
