import{d as r,o as d,c as f,w as s,b as o,Z as c,u as n,dd as u,ey as i,eB as l,bP as p}from"./vue-router.9fdef1c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="933e7fb8-4f14-42a4-94db-7e5cfce6d6ff",e._sentryDebugIdIdentifier="sentry-dbid-933e7fb8-4f14-42a4-94db-7e5cfce6d6ff")}catch{}})();const y=r({__name:"AbstraButton",setup(e){return(t,a)=>(d(),f(n(p),i(l(t.$attrs)),{default:s(()=>[o(n(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:s(()=>[c(t.$slots,"default")]),_:3})]),_:3},16))}});export{y as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.a9d33274.js.map
