import{E as y}from"./api.e2091ab7.js";import{C as w}from"./ContentLayout.e85ba8fa.js";import{d as c,L as g,N as l,e as _,o as a,c as i,w as f,b as n,u as o,R as s}from"./vue-router.9fdef1c2.js";import{K as v,_ as K,W as R,E,a as T}from"./WorkflowView.a4d9cecb.js";import{A as p,T as V}from"./TabPane.c75b1736.js";import"./fetch.37e528cd.js";import"./metadata.7a99eefc.js";import"./PhBug.vue.6c87d690.js";import"./PhCheckCircle.vue.af0e1704.js";import"./PhKanban.vue.2ddab4c5.js";import"./PhWebhooksLogo.vue.d6d363ca.js";import"./polling.42bbddc1.js";import"./asyncComputed.b83fe47e.js";import"./PhQuestion.vue.b4a6c4a3.js";import"./ant-design.57bf02d4.js";import"./index.dc55511c.js";import"./index.c5b0cb5b.js";import"./index.9b0e6eb7.js";import"./CollapsePanel.441f94ae.js";import"./index.3697d291.js";import"./index.3959e4c5.js";import"./Badge.4a06ddb5.js";import"./PhArrowCounterClockwise.vue.d5c399db.js";import"./Workflow.7ba126d6.js";import"./validations.b5a11976.js";import"./string.aab27b65.js";import"./uuid.9da3532f.js";import"./index.12dad819.js";import"./workspaces.38c92808.js";import"./workspaceStore.d7393ddd.js";import"./url.07fafc3a.js";import"./colorHelpers.ceab0a75.js";import"./record.5ebff19c.js";import"./index.ed3a7a98.js";import"./PhArrowDown.vue.5a4a9984.js";import"./Card.2e3b751b.js";import"./LoadingOutlined.1b0aff14.js";import"./DeleteOutlined.1a862633.js";import"./PhDownloadSimple.vue.91626f07.js";import"./utils.09f24d70.js";import"./LoadingContainer.13e81899.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="5015ed4b-100f-4d61-bb89-79bcf404b0a8",r._sentryDebugIdIdentifier="sentry-dbid-5015ed4b-100f-4d61-bb89-79bcf404b0a8")}catch{}})();const yo=c({__name:"WorkflowThreads",setup(r){const t=new E,m=new T,d=new g(l.array(l.string()),"kanban-selected-stages"),u=new y,e=_("kanban");return(W,b)=>(a(),i(w,{"full-width":""},{default:f(()=>[n(o(V),{activeKey:e.value,"onUpdate:activeKey":b[0]||(b[0]=k=>e.value=k)},{default:f(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),e.value==="kanban"?(a(),i(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(d),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),e.value==="table"?(a(),i(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),e.value==="workflow"?(a(),i(R,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.6f570613.js.map
