import{L as a}from"./Logo.df0c7b1a.js";import{d as t,o as n,c as r,u as d}from"./vue-router.9fdef1c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d97466e7-03c4-41fa-8f30-af9b65937dad",e._sentryDebugIdIdentifier="sentry-dbid-d97466e7-03c4-41fa-8f30-af9b65937dad")}catch{}})();const f="/assets/logo.0faadfa2.svg",c=t({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(n(),r(a,{"image-url":d(f),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{c as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.8b0f385b.js.map
