import{P as m}from"./PlayerNavbar.7865c28f.js";import{u as f,i as g}from"./workspaceStore.d7393ddd.js";import{d as h,eo as y,ea as c,e as v,f as b,r as k,o as i,X as w,u as n,c as L,R as I,a as N,b as C,$ as R}from"./vue-router.9fdef1c2.js";import"./metadata.7a99eefc.js";import"./PhBug.vue.6c87d690.js";import"./PhCheckCircle.vue.af0e1704.js";import"./PhKanban.vue.2ddab4c5.js";import"./PhWebhooksLogo.vue.d6d363ca.js";import"./LoadingOutlined.1b0aff14.js";import"./PhSignOut.vue.ea238bb3.js";import"./index.45850dc3.js";import"./Avatar.790cee4f.js";import"./url.07fafc3a.js";import"./colorHelpers.ceab0a75.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="2a24d423-eccb-4d34-9937-147ceb768034",t._sentryDebugIdIdentifier="sentry-dbid-2a24d423-eccb-4d34-9937-147ceb768034")}catch{}})();const V={class:"main-container"},x={class:"content"},B=h({__name:"Main",setup(t){const e=y(),o=f(),u=c().path,a=v(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=b(()=>!!c().meta.hideLogin);return g(()=>e.push({name:"playerLogin"})),(r,s)=>{const _=k("RouterView");return i(),w("div",V,[n(o).state.workspace?(i(),L(m,{key:0,"current-path":n(u),"hide-login":l.value,"runner-data":n(o).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p},null,8,["current-path","hide-login","runner-data","loading"])):I("",!0),N("section",x,[C(_)])])}}});const H=R(B,[["__scopeId","data-v-09fccc95"]]);export{H as default};
//# sourceMappingURL=Main.c089557e.js.map
