import{k as i,T as n,m as r,P as o,C as d,M as c,s as p,n as s,p as f,q as m,t as u,v as g}from"./vue-router.9fdef1c2.js";import{s as b,c as y,a}from"./workspaceStore.d7393ddd.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.2da0a19b.js";import"./url.07fafc3a.js";import"./colorHelpers.ceab0a75.js";import"./PlayerConfigProvider.428d45d2.js";import"./index.12dad819.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b1db84f1-9aac-46da-929c-0fdc5faa8e85",t._sentryDebugIdIdentifier="sentry-dbid-b1db84f1-9aac-46da-929c-0fdc5faa8e85")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=y(),e=i({render:()=>f(l)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",c),e.component("Message",p),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.e1e1b173.js.map
