import{$ as t,r as c,o as s,c as r}from"./vue-router.9fdef1c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d9ae0fa5-2123-4a8c-9752-04cce9eb7b4f",e._sentryDebugIdIdentifier="sentry-dbid-d9ae0fa5-2123-4a8c-9752-04cce9eb7b4f")}catch{}})();const _={};function a(e,o){const n=c("RouterView");return s(),r(n,{class:"router"})}const f=t(_,[["render",a],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.8d382771.js.map
