import{O as d}from"./workspaceStore.d7393ddd.js";import{d as i,W as l,o as c,X as u,b as a,w as n,u as o,aF as s,d9 as f,d8 as b}from"./vue-router.9fdef1c2.js";import"./url.07fafc3a.js";import"./colorHelpers.ceab0a75.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2521ef3c-54b9-43c4-9011-2eb8565aed89",e._sentryDebugIdIdentifier="sentry-dbid-2521ef3c-54b9-43c4-9011-2eb8565aed89")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new d().loginCallback()}),(t,r)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.a0fb8243.js.map
