import{O as r}from"./workspaceStore.d7393ddd.js";import{d as l,W as i,o as c,X as u,b as a,w as o,u as n,aF as d,d9 as f,d8 as _}from"./vue-router.9fdef1c2.js";import"./url.07fafc3a.js";import"./colorHelpers.ceab0a75.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a7909c8c-e157-4edd-9894-f51dc07ee768",e._sentryDebugIdIdentifier="sentry-dbid-a7909c8c-e157-4edd-9894-f51dc07ee768")}catch{}})();const b=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(c(),u("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(_),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{b as default};
//# sourceMappingURL=OidcLogoutCallback.22965b09.js.map
