import{a as g}from"./asyncComputed.b83fe47e.js";import{d as y,ea as _,W as b,u as e,o as l,c as w,X as x,b as a,w as o,d9 as C,aF as p,dd as h,bP as I,a as k,e9 as v}from"./vue-router.9fdef1c2.js";import"./gateway.48c2d7b1.js";import{O as B}from"./organization.decc8448.js";import"./tables.86324cd4.js";import{C as c}from"./router.d2ac8bec.js";import{L as D}from"./LoadingContainer.13e81899.js";import{A as N}from"./index.3697d291.js";import{C as z}from"./Card.2e3b751b.js";import"./popupNotifcation.894bbaa5.js";import"./record.5ebff19c.js";import"./string.aab27b65.js";import"./TabPane.c75b1736.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="5ab2e566-3c48-447f-9f76-234b20cf4441",t._sentryDebugIdIdentifier="sentry-dbid-5ab2e566-3c48-447f-9f76-234b20cf4441")}catch{}})();const M={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},H=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:f,result:u}=g(()=>B.get(s));b(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,j)=>e(f)?(l(),w(D,{key:0})):(l(),x("div",M,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(N),{style:{"margin-top":"0"}}),a(e(z),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(u))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{H as default};
//# sourceMappingURL=Billing.ae086f73.js.map
