import{d as l,eh as c,f as d,o as t,X as n,R as r,e9 as _,$ as g}from"./vue-router.9fdef1c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="bfb874b0-7e20-40d9-8b92-27293292b061",e._sentryDebugIdIdentifier="sentry-dbid-bfb874b0-7e20-40d9-8b92-27293292b061")}catch{}})();const p={class:"logo"},b=["src","alt"],u={key:1},f=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const o=e;c(s=>({"4352941e":a.value}));const a=d(()=>o.size==="large"?"80px":"50px"),i=d(()=>`${o.brandName} Logo`);return(s,m)=>(t(),n("div",p,[s.imageUrl?(t(),n("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,b)):r("",!0),s.hideText?r("",!0):(t(),n("span",u,_(s.brandName),1))]))}});const h=g(f,[["__scopeId","data-v-16688d14"]]);export{h as L};
//# sourceMappingURL=Logo.df0c7b1a.js.map
