import{B as d}from"./BookOutlined.510e5f39.js";import{d as c,o as s,c as f,w as o,b as l,u as n,Z as u,X as i,aF as p,aR as b,bP as y}from"./vue-router.9fdef1c2.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="c7f96ce6-8c05-4af9-8fdc-fa7e06d8a4a5",t._sentryDebugIdIdentifier="sentry-dbid-c7f96ce6-8c05-4af9-8fdc-fa7e06d8a4a5")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),f(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(s(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.1284f4cc.js.map
