import{C as n}from"./gateway.48c2d7b1.js";import"./vue-router.9fdef1c2.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="610017c0-36ea-4451-a11b-adab0a637af0",a._sentryDebugIdIdentifier="sentry-dbid-610017c0-36ea-4451-a11b-adab0a637af0")}catch{}})();class i{async create(t){return n.post(`organizations/${t.organizationId}/members`,{email:t.email})}async delete(t){return n.delete(`organizations/${t.organizationId}/members/${t.authorId}`)}async list(t){return n.get(`organizations/${t}/members`)}async get(t,e){return n.get(`organizations/${t}/members/${e}`)}}const s=new i;class o{constructor(t){this.dto=t}static async list(t){return(await s.list(t)).map(r=>new o(r))}static async create(t,e){const r=await s.create({organizationId:t,email:e});return new o(r)}static async get(t,e){const r=await s.get(t,e);return new o(r)}static async delete(t,e){return s.delete({organizationId:t,authorId:e})}get email(){return this.dto.email}get name(){return this.dto.name}get role(){return this.dto.role}get id(){return this.dto.authorId}get authorId(){return this.dto.authorId}}export{o as M};
//# sourceMappingURL=member.ab9b038b.js.map
