import{eM as n,eN as t}from"./vue-router.9fdef1c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ca0eb61d-764c-4ee1-aafd-061a85fe8e9a",e._sentryDebugIdIdentifier="sentry-dbid-ca0eb61d-764c-4ee1-aafd-061a85fe8e9a")}catch{}})();function f(e,a){return n(1,arguments),t(e,Date.now(),a)}export{f};
//# sourceMappingURL=index.c5b0cb5b.js.map
