import{d as i,o as p,c as a,w as n,b as m,u as t}from"./vue-router.9fdef1c2.js";import"./editor.9acd82f2.js";import{W as s}from"./workspaces.38c92808.js";import{C as d}from"./ContentLayout.e85ba8fa.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.19079fb8.js";import"./workspaceStore.d7393ddd.js";import"./url.07fafc3a.js";import"./colorHelpers.ceab0a75.js";import"./asyncComputed.b83fe47e.js";import"./record.5ebff19c.js";import"./gateway.48c2d7b1.js";import"./popupNotifcation.894bbaa5.js";import"./fetch.37e528cd.js";import"./SaveButton.da7c212b.js";import"./UnsavedChangesHandler.35bc9120.js";import"./ExclamationCircleOutlined.3149f6fb.js";import"./CrudView.f5a5d8e5.js";import"./router.d2ac8bec.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.1284f4cc.js";import"./BookOutlined.510e5f39.js";import"./PhDotsThreeVertical.vue.1dec2e66.js";import"./Badge.4a06ddb5.js";import"./index.dc55511c.js";import"./polling.42bbddc1.js";import"./PhPencil.vue.eb898a6f.js";import"./index.612bc9e7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="617aa1aa-c7a1-4332-8955-8cb960442fb9",o._sentryDebugIdIdentifier="sentry-dbid-617aa1aa-c7a1-4332-8955-8cb960442fb9")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),a(d,null,{default:n(()=>[m(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.2c34b146.js.map
