import{d as n,o as s,X as a,a as d,Z as r,ed as l,$ as _}from"./vue-router.9fdef1c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="736f5215-1004-48a2-b269-3735bafb5d63",e._sentryDebugIdIdentifier="sentry-dbid-736f5215-1004-48a2-b269-3735bafb5d63")}catch{}})();const u={class:"content-layout"},f=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),a("div",u,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(f,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.e85ba8fa.js.map
