import{_}from"./Login.vue_vue_type_script_setup_true_lang.f4d29cbf.js";import{b as m,u as f}from"./workspaceStore.d7393ddd.js";import{d as l,eo as y,ea as b,o as g,X as w,b as k,u,$ as h}from"./vue-router.9fdef1c2.js";import"./Logo.df0c7b1a.js";import"./string.aab27b65.js";import"./CircularLoading.e9b619e0.js";import"./index.12dad819.js";import"./index.612bc9e7.js";import"./url.07fafc3a.js";import"./colorHelpers.ceab0a75.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1776a450-c188-4339-b732-83f276d502ed",e._sentryDebugIdIdentifier="sentry-dbid-1776a450-c188-4339-b732-83f276d502ed")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=y(),r=b(),i=m(),a=f(),p=async()=>{await i.signUp();const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>{var n,c,d;return g(),w("div",v,[k(_,{"logo-url":(c=(n=u(a).state.workspace)==null?void 0:n.logoUrl)!=null?c:void 0,"brand-name":(d=u(a).state.workspace)==null?void 0:d.brandName,onDone:p},null,8,["logo-url","brand-name"])])}}});const $=h(I,[["__scopeId","data-v-fc57ade6"]]);export{$ as default};
//# sourceMappingURL=Login.ddcb1953.js.map
