import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.19079fb8.js";import{d as i,ea as s,o as a,c as m,u as c}from"./vue-router.9fdef1c2.js";import"./gateway.48c2d7b1.js";import"./popupNotifcation.894bbaa5.js";import"./fetch.37e528cd.js";import"./record.5ebff19c.js";import"./SaveButton.da7c212b.js";import"./UnsavedChangesHandler.35bc9120.js";import"./ExclamationCircleOutlined.3149f6fb.js";import"./CrudView.f5a5d8e5.js";import"./router.d2ac8bec.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.1284f4cc.js";import"./BookOutlined.510e5f39.js";import"./url.07fafc3a.js";import"./PhDotsThreeVertical.vue.1dec2e66.js";import"./Badge.4a06ddb5.js";import"./index.dc55511c.js";import"./asyncComputed.b83fe47e.js";import"./polling.42bbddc1.js";import"./PhPencil.vue.eb898a6f.js";import"./index.612bc9e7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="cbed93a0-a2f2-4019-b57b-ccd9267ca47a",o._sentryDebugIdIdentifier="sentry-dbid-cbed93a0-a2f2-4019-b57b-ccd9267ca47a")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(d,f)=>(a(),m(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.d9f48be3.js.map
